dnl
dnl                       Written by JoungKyun.Kim
dnl            Copyright (c) 2011 JoungKyun.Kim <http://oops.org>
dnl
dnl ----------------------------------------------------------------------------
dnl Redistribution and use in source and binary forms, with or without
dnl modification, are permitted provided that the following conditions are met:
dnl
dnl     * Redistributions of source code must retain the above copyright notice,
dnl       this list of conditions and the following disclaimer.
dnl
dnl     * Redistributions in binary form must reproduce the above copyright
dnl       notice, this list of conditions and the following disclaimer in the
dnl       documentation and/or other materials provided with the distribution.
dnl
dnl     * Neither the name of JoungKyun.Kim nor the url of oops.org
dnl       nor the names of their contributors may be used to endorse or
dnl       promote products derived from this software without specific prior
dnl       written permission.
dnl
dnl THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
dnl AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
dnl IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
dnl ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
dnl LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
dnl CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
dnl SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
dnl INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
dnl CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
dnl ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
dnl POSSIBILITY OF SUCH DAMAGE.
dnl ----------------------------------------------------------------------------
dnl  This file is part of olibc.
dnl
dnl  $Id: olibc.m4.in 443 2011-05-01 15:21:28Z oops $
dnl

AC_DEFUN([AX_OLIBC_WITH],
[
	if test "x$with_olibc" != "x"; then
		if test "x$with_olibc" = "xyes"; then
			olibcconfig="/usr/bin/olibc-config"
		else
			olibcconfig="$with_olibc"
		fi
	else
		olibcconfig="/usr/bin/olibc-config"
	fi

	AC_MSG_CHECKING(for olibc-config path)
	if test ! -f "$olibcconfig" || test ! -x "$olibcconfig"; then
		if test $olibc_check_failed -eq 1; then
			AC_MSG_ERROR(can't find $olibcconfig)
		else
			olibcconfig=
			AC_MSG_RESULT([not found])
		fi
	else
		AC_MSG_RESULT([$olibcconfig])
	fi
])

AC_DEFUN([AX_OLIBC_HEADER],
[
	#
	# olibc header check
	#
	OLIBC_INCLUDES="`$olibcconfig --includes 2> /dev/null`"
	if test -z "$OLIBC_INCLUDES"; then
		OLIBC_INCLUDES="`$olibcconfig --defs 2> /dev/null | sed 's/[[ ]]*-D[[^ ]]*//g'`"
	fi

	ret_cppflags=0
	for check_cppflags in $CPPFLAGS
	do
		test -z "$OLIBC_INCLUDES" && break

		if test "$check_cppflags" = "$OLIBC_INCLUDES"; then
			ret_cppflags=1
			break
		fi
	done
	test $ret_cppflags -eq 0 && CPPFLAGS="$OLIBC_INCLUDES $CPPFLAGS"
	AC_CHECK_HEADERS(oc_type.h)
	if test "$ac_cv_header_oc_type_h" != "yes"; then
		AC_MSG_ERROR([You must need oc_type.h header file])
	fi
])

AC_DEFUN([AX_OLIBC_LD],
[
	#
	# olibc library check
	#
	OLIBC_LDFLAGS="`$olibcconfig --ldflags 2> /dev/null`"

	olibc_OLD_LDFLAGS="$LDFLAGS"
	LDFLAGS="$OLIBC_LDFLAGS"
	AC_CHECK_LIB(
		$ac_olibc_name, $ac_olibc_check_symbol, [
			case "$ac_olibc_name" in
				ogc)
					AC_DEFINE(
						[HAVE_LIBOGC], 1,
						[Define to 1 if you have the `ogc' library (-logc).])
					;;
				oc)
					AC_DEFINE(
						[HAVE_LIBOC], 1,
						[Define to 1 if you have the `oc' library (-loc).])
					;;
				*)
					AC_DEFINE(
						[HAVE_LIBOLIBC], 1,
						[Define to 1 if you have the `olibc' library (-lolibc).])
					;;
			esac
			LIBS="`$olibcconfig --libs 2> /dev/null` $LIBS"
		],[
			if test $olibc_check_failed -eq 1; then
				AC_MSG_ERROR([Can't not found `$ac_olibc_name' library (-l$ac_olibc_name)])
			fi
		]
	)
	LDFLAGS="$olibc_OLD_LDFLAGS"

	ret_ldflags=0
	for check_ldflags in $LDFLAGS
	do
		test -z "$OLIBC_LDFLAGS" && break

		if test "$check_ldflags" = "$OLIBC_LDFLAGS"; then
			ret_ldflags=1
			break
		fi
	done

	test $ret_ldflags -eq 0 && LDFLAGS="$OLIBC_LDFLAGS $LDFLAGS"
])

AC_DEFUN([AX_OLIBC_LIBTOOL],
[
	#
	# olibc library check
	#
	AC_MSG_CHECKING(for $ac_olibc_check_symbol in -l$ac_olibc_name)

	OLIBC_LIBS="`$olibcconfig --link-libtool 2> /dev/null`"

	if test "x$OLIBC_LIBS" = "x"; then
		AC_MSG_RESULT([no])
		if test $olibc_check_failed -eq 1; then
			AC_MSG_ERROR([Can't not found `$ac_olibc_name' libtool library ($ac_olibc_name.la)])
		fi
	else
		AC_MSG_RESULT([yes])
		LIBS="$OLIBC_LIBS $LIBS"
		case "$ac_olibc_name" in
			ogc)
				AC_DEFINE(
					[HAVE_LIBOGC], 1,
					[Define to 1 if you have the `ogc' library (-logc).])
				;;
			oc)
				AC_DEFINE(
					[HAVE_LIBOC], 1,
					[Define to 1 if you have the `oc' library (-loc).])
				;;
			*)
				AC_DEFINE(
					[HAVE_LIBOLIBC], 1,
					[Define to 1 if you have the `olibc' library (-lolibc).])
				;;
		esac
	fi
])

dnl
dnl Usage AX_OLIBC
dnl     AX_OLIBC([library type],[stop on failed])
dnl         library type : ld or libtool
dnl         stop on failed : 1 => stop, 0 => continue
dnl
dnl     AX_OLIBC([library type])
dnl     AX_OLIBC(1)
dnl
dnl     no argument on AX_OLIBC
dnl         library type   = ld
dnl         stop on failed = 0
dnl
AC_DEFUN([AX_OLIBC],
[
	ax_olibc_argc=$#
	olibc_check_failed=0

	if test $ax_olibc_argc -gt 0; then
		ax_olibc_first_arg=$1
		ax_olibc_second_arg=$2
	fi

	if test $ax_olibc_argc -gt 0; then
		if test $ax_olibc_argc -eq 2; then
			if test "$ax_olibc_first_arg" = "libtool"; then
				olibc_ld_mode="libtool"
			elif test "$ax_olibc_first_arg" = "ld"; then
				olibc_ld_mode="ld"
			else
				AC_MSG_ERROR([Unsupported link type on AX OLIBC macro])
			fi

			if test $ax_olibc_second_arg -eq 1; then
				olibc_check_failed=1
			fi
		elif test $ax_olibc_argc -eq 1; then
			if test "$ax_olibc_first_arg" = "libtool"; then
				olibc_ld_mode="libtool"
			elif test "$ax_olibc_first_arg" = "ld"; then
				olibc_ld_mode="ld"
			elif test $ax_olibc_first_arg -eq 1 || test $ax_olibc_first_arg -eq 0 ; then
				olibc_check_failed=$ax_olibc_first_arg
			else
				AC_MSG_ERROR([Unsupported argument value on AX OLIBC macro])
			fi
		else
			AC_MSG_ERROR([So many arguments on AX OLIBC macro])
		fi
	fi

	AC_ARG_WITH(olibc,
		[  --with-olibc=PATH      path of olibc-config [[default: /usr/bin/olibc-config]]])

	if test "x$with_olibc" != "xno"; then
		AX_OLIBC_WITH
		if test "x$olibcconfig" != "x"; then
			ac_olibc_name="`$olibcconfig --libname 2> /dev/null`"
			if test "x$ac_olibc_name" = "x"; then
				ac_olibc_name="olibc"
			fi
		else
			ac_olibc_name="olibc"
		fi

		if test "$ac_olibc_name" = "ogc"; then
			ac_olibc_check_symbol="convert_punycode"
		else
			ac_olibc_check_symbol="join"
		fi

		if test "$olibc_ld_mode" = "libtool"; then
			AX_OLIBC_LIBTOOL
		else
			AX_OLIBC_LD
		fi
		AX_OLIBC_HEADER
	else
		if test $olibc_check_failed -eq 1; then
			AC_MSG_ERROR([--without-olibc doesn't permit])
		fi
	fi
])
